# libpythonproubuntu
## Projeto para exemplificar construção de projetos Python no curso Pytools. Projeto refeito utilizando Ubuntu e GitHub Actions.
##  Projeto original feito com Windows e Travis CI: [libpythonpro](https://github.com/mateuslourenco/libpythonpro)

### Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://www.python.pro.br)

Suportado versão 3 de Python

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:
```console
flake8
```

Tópicos a serem abordados
 1. Git
 2. Virutalenv
 3. Pip

[![Python application](https://github.com/mateuslourenco/libpythonproubuntu/actions/workflows/python-app.yml/badge.svg)](https://github.com/mateuslourenco/libpythonproubuntu/actions/workflows/python-app.yml)
[![Updates](https://pyup.io/repos/github/mateuslourenco/libpythonproubuntu/shield.svg)](https://pyup.io/repos/github/mateuslourenco/libpythonproubuntu/)
[![Python 3](https://pyup.io/repos/github/mateuslourenco/libpythonproubuntu/python-3-shield.svg)](https://pyup.io/repos/github/mateuslourenco/libpythonproubuntu/)
